#include "defines.h"

#include <Arduino.h>
#include <arduino-timer.h>
#include <Bounce2.h>
#include <usb_joystick.h>

Timer<1, micros> TxTimer;
Bounce2::Button * buttons = new Bounce2::Button[NUM_BUTTONS];
const uint8_t BUTTON_PINS[NUM_BUTTONS] = {GEAR1, GEAR2, GEAR3, GEAR4, GEAR5, GEAR6};

bool TxJoystick(void *) {
  Joystick.send_now();
  return true;
}

void setup() {
  //Enable manual send of joystick packets
  Joystick.useManualSend(true);

  //Attach buttons to debounce library. pullup, pressed state is low
  for (int i = 0; i < NUM_BUTTONS; i++) {
    buttons[i].attach( BUTTON_PINS[i] , INPUT_PULLUP  );  //setup the bounce instance for the current button
    buttons[i].interval(5);  // interval in ms
    buttons[i].setPressedState(LOW);
  }

  TxTimer.every(1000, TxJoystick);
}

void loop() {
  //Read buttons and update joystick state.
  for (int i = 0; i < NUM_BUTTONS; i++) {
    buttons[i].update();
    Joystick.button(i+1, buttons[i].isPressed());
  }
  
  //Transmit USB packet
  TxTimer.tick();

}
